v1alpha1

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 31, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package v1alpha1 contains API Schema definitions for the proxy v1alpha1 API group +kubebuilder:object:generate=true +groupName=proxy.lindex.com

Index

Constants

This section is empty.

Variables

var (
	// GroupVersion is group version used to register these objects
	GroupVersion = schema.GroupVersion{Group: "proxy.lindex.com", Version: "v1alpha1"}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)

Functions

This section is empty.

Types

type TSProxy

type TSProxy struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   TSProxySpec   `json:"spec,omitempty"`
	Status TSProxyStatus `json:"status,omitempty"`
}

TSProxy is the Schema for the tsproxies API

func (*TSProxy) DeepCopy

func (in *TSProxy) DeepCopy() *TSProxy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TSProxy.

func (*TSProxy) DeepCopyInto

func (in *TSProxy) DeepCopyInto(out *TSProxy)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TSProxy) DeepCopyObject

func (in *TSProxy) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type TSProxyList

type TSProxyList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []TSProxy `json:"items"`
}

TSProxyList contains a list of TSProxy

func (*TSProxyList) DeepCopy

func (in *TSProxyList) DeepCopy() *TSProxyList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TSProxyList.

func (*TSProxyList) DeepCopyInto

func (in *TSProxyList) DeepCopyInto(out *TSProxyList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TSProxyList) DeepCopyObject

func (in *TSProxyList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type TSProxyService

type TSProxyService struct {
	//+required
	// Name of the service to proxy
	Name string `json:"name"`

	//+required
	// +kubebuilder:validation:Minimum=1
	// +kubebuilder:validation:Maximum=65535
	// +kubebuilder:validation:ExclusiveMinimum=false
	// +kubebuilder:validation:ExclusiveMaximum=false
	// ServicePort contains the port on the service to proxy
	ServicePort int32 `json:"port"`

	//+required
	// +kubebuilder:validation:Minimum=1
	// +kubebuilder:validation:Maximum=65535
	// +kubebuilder:validation:ExclusiveMinimum=false
	// +kubebuilder:validation:ExclusiveMaximum=false
	// ExposeAs contains the port to expose the proxy on the host network
	ExposeAs int32 `json:"exposeAs"`
}

func (*TSProxyService) DeepCopy

func (in *TSProxyService) DeepCopy() *TSProxyService

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TSProxyService.

func (*TSProxyService) DeepCopyInto

func (in *TSProxyService) DeepCopyInto(out *TSProxyService)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TSProxySpec

type TSProxySpec struct {
	Services []TSProxyService `json:"services,omitempty"`
}

TSProxySpec defines the desired state of TSProxy

func (*TSProxySpec) DeepCopy

func (in *TSProxySpec) DeepCopy() *TSProxySpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TSProxySpec.

func (*TSProxySpec) DeepCopyInto

func (in *TSProxySpec) DeepCopyInto(out *TSProxySpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TSProxyStatus

type TSProxyStatus struct {
}

TSProxyStatus defines the observed state of TSProxy

func (*TSProxyStatus) DeepCopy

func (in *TSProxyStatus) DeepCopy() *TSProxyStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TSProxyStatus.

func (*TSProxyStatus) DeepCopyInto

func (in *TSProxyStatus) DeepCopyInto(out *TSProxyStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to